@@ -82,12 +82,16 @@ def get_client(oauth=False):
         
         client = asana.Client.access_token(config['asana_token']['access_token'])
         if client.session.authorized == False:
-            print("Token expired, getting new token")
+            print("Insufficient token found. Getting new token")
             token, client = get_oauth_token(config)
         else:
-            print("Token is still valid")     
-            client = asana.Client.access_token(config['asana_token']['access_token'])
-            
+            try:
+                client = asana.Client.access_token(config['asana_token']['access_token'])
+                print(f"Token found. Using token: {client.users.me()}")
+            except asana.error.NoAuthorizationError:
+                print("Insufficient token found. Getting new token...")
+                token, client = get_oauth_token(config)
+
     return client
 
 
@@ -145,14 +149,14 @@ def add_todo(task_text, expected_duration, workspace_id, project_name):
         tar_date = f"{tm.tm_year}-{tm.tm_mon:02d}-{day:02d}"
     
     
-    client = get_client()
+    client = get_client(True)
     me = client.users.me()
     
     if workspace_id is None: workspace_id = me['workspaces'][0]['gid']
     
     
     projects = list(client.projects.get_projects_for_workspace(workspace_id))
-    if project_name is 0:
+    if project_name == 0:
         # here project_name is id
         project_id = projects[int(project_name)]['gid']
     else:
@@ -179,14 +183,14 @@ def add_todo(task_text, expected_duration, workspace_id, project_name):
     print(json.dumps(result, indent=4))
     
 def done_todo(task_id):
-    client = get_client()
+    client = get_client(True)
     data =  {'completed': True}
     result = client.tasks.update_task(task_id, data)
     print(json.dumps(result, indent=4))
 
 def fix_past_due(workspace_name):
     df = asana_get_todos(workspace_name,None)
-    client = get_client()
+    client = get_client(True)
     
     # select all that are past due
     df = df[df['completed'] == False]
